==> geopsypack-src-3.3.4.tar.gz: geopsypack-src-3.3.4/QGpGuiMath/src/CurvePlotProxy.h <==
/***************************************************************************
**
**  This file is part of QGpGuiMath.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This file is distributed in the hope that it will be useful, but WITHOUT
**  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
**  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
**  License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2016-08-25
**  Copyright: 2016-2019
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#ifndef CURVEPLOTPROXY_H
#define CURVEPLOTPROXY_H

#include <SciFigs.h>

#include "QGpGuiMathDLLExport.h"

namespace QGpGuiMath {

  class QGPGUIMATH_EXPORT CurvePlotProxy
  {
  public:
    CurvePlotProxy() {}
    virtual ~CurvePlotProxy() {}

    virtual void setXAxisProperties(Axis *) {}
    virtual void setYAxisProperties(Axis *) {}

    virtual void setCurve(AbstractLine * line, CurveProxy * proxy)=0;
  };

} // namespace QGpGuiMath

#endif // CURVEPLOTPROXY_H

==> geopsypack-src-3.5.2.tar.gz: geopsypack-src-3.5.2/QGpGuiMath/src/CurvePlotProxy.h <==
/***************************************************************************
**
**  This file is part of QGpGuiMath.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This file is distributed in the hope that it will be useful, but WITHOUT
**  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
**  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
**  License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2016-08-25
**  Copyright: 2016-2019
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#ifndef CURVEPLOTPROXY_H
#define CURVEPLOTPROXY_H

#include <SciFigs.h>

#include "QGpGuiMathDLLExport.h"

namespace QGpGuiMath {

  class QGPGUIMATH_EXPORT CurvePlotProxy
  {
  public:
    CurvePlotProxy() {}
    virtual ~CurvePlotProxy() {}

    virtual void setXAxisProperties(Axis *) {}
    virtual void setYAxisProperties(Axis *) {}

    virtual void setCurve(AbstractLine * line, CurveProxy * proxy) const=0;
  };

} // namespace QGpGuiMath

#endif // CURVEPLOTPROXY_H
